.galaxy-uibuilder .ui-form-element.section-row.pl-2 {
  padding: 0px 2px;
  margin-left: 10px;
  border-left: 2px solid rgb(221, 218, 196);
  border-radius: 5px;
}

.galaxy-uibuilder .ui-form-element.section-row {
  padding: 0px 2px;
  margin-bottom: 10px;

}

.galaxy-uibuilder .Galaxy-form input:not(.fileid, .buttonid, [type='checkbox']){

  width: 99%;
  padding: 12px 20px;
  margin: 8px 0;
  display: inline-block;
  border: 1px solid #ccc;
  border-radius: 4px;
  box-sizing: border-box;
}

.galaxy-uibuilder .Galaxy-form select{
  /* width: 100%; */
  padding: 12px 20px;
  margin: 8px 0;
  display: inline-block;
  border: 1px solid #ccc;
  border-radius: 4px;
  box-sizing: border-box;
}

.galaxy-uibuilder .ui-form-element.section-row span {
  font-weight: bold;
}

.galaxy-uibuilder .upload_data {
  display: inline-block;
  border: 1px solid rgb(212, 41, 41);
  box-sizing: border-box;
}

.galaxy-uibuilder .Galaxy-form input[type="file"] {
  display: none;
}

.galaxy-uibuilder .custom-file-upload {
  border: 1px solid rgb(212, 41, 41);
  display: inline-block;
  padding: 6px 12px;
  cursor: pointer;
}

.galaxy-uibuilder .ui-form-element.section-row label :not(.ui-checkbox-label){
  width: 100%;
  display: inline-block;
  padding: 6px 12px;
  cursor: pointer;
}

.galaxy-uibuilder .ui-checkbox-label {
  width: 95%;
  padding-bottom: 2px;
  margin-left: 5px;
}

.galaxy-uibuilder .outer-checkbox-div {
  width: 95%;
  margin-left: 20px;
  margin-top: 10px;
  padding-left: 5px;
  padding-top: 5px;
  border: solid 1px rgb(168,150,150);
  border-radius: 5px;
}

.galaxy-uibuilder button.delete-button{
  margin-top: 10px
}


.galaxy-uibuilder .collapsible{
  border-radius: 0px;
  border-top-left-radius:2px; 
  border-top-right-radius: 2px; 
}

.galaxy-uibuilder .internal-ui-repeat.section-row{

  border-radius: 0px;
  margin-left: 5px;
  border-bottom-left-radius: 5px;
  border-left: 2px rgb(168,162,162) solid;
}

.galaxy-uibuilder .repeat-ui-from-title{
  margin-top: 10px;
  background-color: rgb(211,207,207);
  height: 40px;
  border-radius: 0px;
}

.galaxy-uibuilder button.RepeatButton { 
  margin: 5px;
  background-color: rgb(91,87,84);
  color: white;
}

.sub-group{
  padding-left: 30px;
}

.icon.fa.mr-1.fa-plus{
  margin-top: 2px;
  margin-left: 2px;
  margin-right: 5px;
  float: left;
  color: rgb(255,255,255);
  background: black;
  padding: 1px;
  font-size: 10px;
}

.icon.fa.mr-1.fa-minus{
  margin-top: 2px;
  margin-left: 2px;
  margin-right: 5px;
  float: left;
  color: rgb(255,255,255);
  background: black;
  padding: 1px;
  font-size: 10px;
}

.ui-options-list.drilldown-container {
  width: 100%;
  border: 1px solid #ccc;
  border-radius: 4px;
}

.galaxy-uibuilder .drill-down.container{
    
  border-width:1px;
  border-style:solid;
  border-color:rgb(159,149,149);
  border-radius: 5px;
  padding-top: 5px;
}

.galaxy-uibuilder .select-unselect{
  margin-bottom: 10px;
  margin-top: 10px;
}

.galaxy-uibuilder .select-ui-form-title-text {
  background: rgb(191,197,197);
  padding: 2px;
  padding-left: 5px;
  padding-right: 5px;
  border-radius: 3px;
}
.galaxy-uibuilder .unselect-ui-form-title-text {
  background: rgb(191,197,197);
  padding: 2px;
  padding-left: 5px;
  padding-right: 5px;
  border-radius: 3px;
}

.unselect-ui-form-title-text:hover {
  background-color: rgb(47,45,84);
  color: white;
}

.select-ui-form-title-text:hover {
  background-color: rgb(47,45,84);
  color: white;
}

.drill-down.container{
  margin-left: 20px;
  background: rgb(255,255,255);
}

.galaxy-uibuilder .ui-radiobutton{
  display:inline;
  float:left;   
  padding-top: 12px;
  padding-right: 4px;
}

.galaxy-uibuilder .ui-option{
  border: 1px solid #bab1b1;
  background: rgb(218,217,215);
}

.galaxy-uibuilder .input-file-type{
  margin-left: 30px;
  margin-bottom: 10px;
}
.galaxy-uibuilder .fa.fa-times-circle{
  color: red;
  font-size: 15px;
  background-color: white;
  border-radius: 9px;
  }

.galaxy-uibuilder .login-form-div{
  background-color: rgb(246,246,246);
  padding: 10px;
}

.galaxy-uibuilder .tabcontent input{
    
    width: 100%;
    height: 30px;
    border: 1px;
}
    
.galaxy-uibuilder .tabcontent input:hover{
    
    width: 100%;
    height: 30px;
    border: 1px rgb(38,38,45) solid;
}
  
.galaxy-uibuilder .login-form .auth-successful{
  background-color: rgb(129, 233, 130);
  padding: 3px;
  border-radius: 3px; 
}

.galaxy-uibuilder .login-form .auth-error{
  background-color: rgb(241,153,153);
  padding: 3px;
  border-radius: 3px;
}

.galaxy-uibuilder .login-form .auth-error p {
  margin: 10px;
}

.galaxy-uibuilder .login-form .auth-successful p {
   margin: 10px; 
}

.galaxy-uibuilder #upload{

  height: 200px;
}

.galaxy-uibuilder #inputupload {
  height: 50px;
}



.galaxy-uibuilder  .form-restore-div{
  background: rgb(53, 53, 54);
  padding-left: 10px;
  width: 98%;
  float: right;
  color: white;
  height: 35px;
  border-radius: 2px;
  padding-top: 2px;
  padding-bottom: 2px;
  margin-bottom: 5px;
}


.galaxy-uibuilder .job-status-footer div {
  overflow: auto;
}
.galaxy-uibuilder .job-status-footer {
  overflow: auto;
}
.galaxy-uibuilder .job-header {
   overflow: auto;
}

.galaxy-uibuilder .jp-mod-selected .form-restore-div {
  background: rgb(15, 16, 20);
}


.galaxy-uibuilder .combo-box .InputData::-webkit-inner-spin-button {
  margin: 0px;
  border: none;
  width: 98%;
  opacity: 1
}

.galaxy-uibuilder .combo-box .login-input-div{
  border: 1px rgb(157, 147, 147) solid;
  width: 100%;
}

.galaxy-uibuilder .combo-box .InputData:hover {
  border: none;
  width: 100%;
  border: solid 1px black;
}

.galaxy-uibuilder .combo-box li{
  background: rgb(18,2,56);
  width: 100%;
  color: rgb(244, 244, 244);
  padding: 5px;
}

.galaxy-uibuilder .combo-box li:hover{
  background: rgb(88,88,96);
  color: rgb(255, 246, 246);
  width: 100%;
  padding-top: 5px;
  border-left: solid rgb(132,129,129) 1px;
  border-top: solid rgb(131,130,130) 1px;
}

.galaxy-uibuilder .combo-box ul{
  background: rgb(13, 12, 12);
  list-style: none;
  display: none;
  margin-left: 10px;
  width: 98%;
  /* border: solid 1px red; */
  position: relative; /* or absolute or fixed */
  z-index: 1; 
  padding: 0; /* Remove padding */
  height: 100px;
  overflow-y: auto; 
  overflow-x: hidden; 
}

.galaxy-uibuilder .combo-box {
  width: 100%;
  height: 80px;
}

.combo-box  .input-wrapper {
  position: relative;
  display: inline-block;
  margin-top: 10px;
  width: 100%;
  height: 30px;
}

.combo-box  .input-wrapper::after {
  content: "";
  position: absolute;
  top: 80%;
  right: 8px;
  transform: translateY(200%);
  width: 0;
  height: 0;
  border-style: solid;
  border-width: 8px 6px 0 6px;
  border-color: rgb(26, 24, 24) transparent transparent transparent;
  pointer-events: none;
}

.combo-box  .InputData {
  width: 100%;
  height: 100%;
}

.galaxy-uibuilder .combo-box .server-name{
  /* margin-left: 10px; */
  size: 12px;
  font-weight: bold;
  /* margin: 2px; */
}

.galaxy-uibuilder #datalist-update{
    
  background: rgb(228, 220, 220);
  width: 100px;
  height: 30px;
}

.galaxy-uibuilder .ul-login{
  border-radius: 2px;
}
.galaxy-uibuilder .tool-forms {
  float:left;
  width:70%;
  height:100%;
  margin-right: 10px;
  background-color: rgb(246,246,246);
  border-radius: 5px;
  }
  
.galaxy-uibuilder #login-email {
    height: 60px;
  }

.galaxy-uibuilder #login-password {
    height:  60px;
  }

.galaxy-uibuilder #refresh-button {
    width: 150px;
    margin-top: 10px
}

.galaxy-uibuilder .form-restore-div #migra-label {
  float: left;
  margin: 10px;
}


.jp-mod-selected .ui-form-title-text b {
  float: left;
  margin: 5px;
  font-size: 15px;
}

.galaxy-uibuilder #datalist-update .fa-refresh {
  float: right;
  margin: 5px;
  font-size: 20px;
}

.galaxy-uibuilder #datalist-update .fa-pulse {
  float: right;
  margin: 5px;
  font-size: 20px;
}

.galaxy-uibuilder .inner-title-div{
  background: rgb(174,175,185);
  margin-top: 10px;
  padding: 10px
}

.galaxy-uibuilder .ui-from-title{

  margin-left: 5px;
  padding-top: 5px; 
}

/* Migration tool */
.migration-tool {
  display: flex;
  flex-direction: column;
}

#button-tool-refresh {
  height: 30px;
  float: right;
  margin-right: 10px;
  min-width: 30%;
  border: 0px;

}

.migration-tool .form-restore-div {
  display: flex;
  flex-wrap: wrap;
}
.migration-tool .tool-migration-select {
  height: 30px;
  width: 100%;
  margin-top: 2px;
  border: 0px;   
}

.migration-tool .div-tool-migration {
  flex: 1;
  margin-right: 10px; /* Adjust margin as needed */
  
}

.button-div {
  flex-basis: 20%;
  margin-top: 2px; /* Adjust margin as needed */
  height: 30px;
  min-width: 30%;
  width: 20%;
}


#migra-refresh-btn{
  color: rgb(16, 16, 16);
  font-size: 16px ; 
  margin-bottom: 5px;
}

.galaxy-uibuilder  .InputDataFile {
  width: 99%    ;
}

.datatypes_options {
  width: 100%;
}
.genomes_options {
   width: 100%;
  
}
.galaxy-uibuilder #upload {
  height: 150px;
}

.galaxy-uibuilder .input_upload{
  width: 98%;
  margin-left: 1%;
  margin-right:  1%;
  height: 150px; 
}

.galaxy-uibuilder .upload_tab .tab {
  margin-top: 10px;
  margin-left: 10px;
  margin-bottom: 10px;
}
#create_data b {
  margin-left: 10px;
}