.galaxy-uibuilder .RepeatButton {

    z-index: 1;
    background-color: var(--jp-layout-color2);
    border: 1px solid var(--jp-border-color1);
    padding: 6px 12px;
    font-size: 0.9em;
    cursor: pointer;
    margin: 5px;
}

.galaxy-uibuilder .collapsible {
  background-color: #777;
  border: 1px #777 solid;
  color: white;
  cursor: pointer;
  padding-top: 10px;
  padding-bottom: 10px;
  border: none;
  text-align: left;
  outline: none;
  font-size: 15px;
  width: 95%;
  margin: 0px;
  margin-left: 0.5%;
  margin-top: 5px;
  padding-left: 2%;
  padding-right: 2%;
  border-radius: 0px;
  border-top-left-radius:2px; 
  border-top-right-radius: 2px; 
}

  .galaxy-uibuilder .active, .collapsible:hover {
    background-color: #555;
  }
  
  .galaxy-uibuilder .content {
    padding: 0 18px;
    display: none;
    overflow: hidden;
    background-color: #f1f1f1;
  }

.galaxy-uibuilder .UPD {
    border: solid;
    border-color: rgb(170, 161, 161);
    border-width: 5px;
    border-left-width: 2px;
    border-right-width: 0px;
    border-bottom-width: 0px;
    border-top-width: 0px;
    border-top-left-radius: 5px;
    border-bottom-left-radius: 5px;
}

/* .galaxy-uibuilder .internal-ui-repeat .section-row {
    border-color: rgb(32, 156, 156);
    border-width: 5px;
} */

.galaxy-uibuilder .delete-button {
  
  background: none;
  border: none;
  cursor: pointer;
  float: right;
}

.galaxy-uibuilder .input-title {
    padding: 10px;
}

.galaxy-uibuilder .dataset-list {
  background: rgb(182, 179, 179);
  float: left;
  width: 23%;
  margin-bottom: 0px;
  border-radius: 3px;

}

.galaxy-data-panel {
height: 400px; 
overflow-y: scroll;
}

.data-set-row {
list-style-type: none;
height: 30px;
margin: 2px;
background: rgb(163, 167, 167);
padding: 10px;
width: 350px;
}

.help-button {
  background-color: rgb(143, 145, 145);
  color: rgb(255, 255, 255);
  cursor: pointer;
  padding: 18px;
  width: 100%;
  border: none;
  text-align: left;
  outline: none;
  font-size: 15px;
  font-weight: bold;
  margin-top: 10px;
}

.active, .help-button:hover {
  background-color: rgb(97, 99, 99);
}

.help-content {
  padding: 18px;
  display: none;
  overflow: hidden;
  background-color: #f1f1f1;
  /* border:2px solid black; */
  border-bottom:1px solid rgb(65, 60, 60);
  border-left: 1px solid rgb(65, 60, 60);
  border-right: 1px solid rgb(65, 60, 60);

  padding-top: 10px;
  padding-left: 10px;
  padding-right: 10px;
  padding-bottom: 10px;
}

.mb-2 .ui-button-check {
  display: inline-block;
}

.drill-down-main {

  border: 1px solid rgb(134, 128, 128);

}

.ui-option {

  border: 2px solid rgb(128, 111, 95);
  border-radius: 2px;
  position:  relative;
  float: left;

}

.multi-selectbox{
  width: 100%;  
}

.job-status-widget{
  background: hsl(0, 4%, 66%);
  width: 90%;
}

.job-header{
  width: 100%;
  height: 34px;
  /* background: hsl(240, 56%, 23%); */
  background: #2c3143;
}

.indicator{
  /* background: hsl(240, 4%, 22%); */
  float: left;
  width: 5%;
  height: 32px;
}

.job-status{
  /* background: hsl(240, 4%, 22%); */
  width: 74%;
  float: left;
  height: 32px;
}

.tool-form-reset{
  /* background: hsl(240, 4%, 22%); */
  width: 5%;
  float: right;
  height: 30px;
}
  
.rerun-button{
  height: 100%;
  width: 100%;
}

.job-input-files{
  background: hsl(0, 85%, 48%);
  width: 380px;
  height: 250px;
}

.job-output-files{
  background: rgb(255, 255, 255);
  height: 90%;
  overflow-x: auto;
  overflow-y: auto;
  border-left: solid 1px #2B2B2B;
  border-right: solid 1px #2B2B2B;
}

.output-file-names {
  overflow-x: auto;
  overflow-y: auto;
  margin-left: 10px;
  background: rgb(255, 255, 255);
}
  
.gear-rotate{
  width: 2em;
  height: 2em;
  font-size: 5px;
  top: 8%;
  left: 4%; 
  background: #E9E581;
  position: relative;
  border-radius: 1em;
  -webkit-animation: 1s gear-rotate linear infinite;
  -moz-animation: 1s gear-rotate linear infinite;
  animation: 1s gear-rotate linear infinite;
  display: block;
  margin-left: 3px;
  margin-top: 3px;
  font-size: 10px;
  text-align: center;
} 

.job-id{  
  text-align: center;
  font-size: 15px;
  float: left;
  color: #ffffff;
  height:  30px;
  margin-left: 10px;
  margin-top: 5px;
}

.job-footer{
  /* background: hsl(240, 4%, 22%); */
  width: 100%;
  height:  20px;
  float: right;
}

.job-detail-text-name {
  float: left;
  text-align: center;
  font-size: 15px;
  color: #ffffff;
}

.job-done-text {
  text-align: center;
  font-size: 15px;
  color: #ffffff;
  display: block;
  width: 10%;
  float: left;
  /* background: hsl(240, 4%, 22%); */
  height: 100%;
}

.job-state-text{
  font-weight: 600;
  height: 100%;
  margin-top: 5px;
}

.job-done-icon{
  display: none;
  width: 100%;
  height: 100%;
  color: #47EC19;
  font-size: 22px;
  display: none;
  text-align: center;

}

.job-error-icon{
  display: block;
  width: 100%;
  height: 100%;
  color: #ec1919;
  display: none;
  text-align: center;
  font-size: 22px;
}
  
  .gear-rotate-icon{
  display: none;
  width: 100%;
  height: 100%;
  display: block;
  float: left;
  margin-left: 3px;
  font-size: 28px;
  color: rgb(233,230,146);
} 

.rbtn {
  border: none;
  background: none;
  font-size: 22px;
  color: white;
  text-align: center;
}

.rbtn:hover {
  border: none;
  background: none;
  font-size: 22.5px;
}

.data-description {
font-size: 10px;
}

.data-header{
font-size: 12px;
}

.Galaxy-form-div {
margin:0;
width:100%;
height:100%;
overflow:hidden;
} 

.tool-forms {
/* float:left; */
width:60%;
height:100%;
background-color: rgb(246,246,246);
border-radius: 5px;
} 



#dataset-history-label{
  height: 5px;
}



.upload-title{
  margin: 10px;
  font-weight: bold;
}

.tablinks{ 
  width: 100px;
  height: 25px;
  border: 0px;
  background-color: rgb(207,210,219)  
}

.tablinks:hover{
  background-color: rgb(54,52,71);
  color: white;
}

.job-output-files{
  height: 200px;
}

.job-details{
  width: 5%;
  height: 30px;
  float: left;
  /* background: hsl(240, 4%, 22%); */
}

.job-details-icon{
  width: 95%;
  height: 95%;
}

.rbtni{
  border: hsl(240, 4%, 22%);
}

.job-status-footer{
  /* background: hsl(240, 4%, 22%); */
  background: #2c3143
}

.footer-txt{
  font-size: 16px;
  color: white;
  margin-left: 20px;
  padding-top: 5px;
}

.job-status-buttons .icon-btn.display-btn{
  border-radius: 0px 0px 0px 0px;
  margin: 1px;
}

.job-status{
  /* background: hsl(240, 4%, 22%); */
  /* width: 74%; */
  float: left;
  height: 100%;
}

.job-status-footer {
  margin-top: 2px;
}

.preview{
  float: left;
  height: 800px;
  padding: 15px;
  width: 95%;
}

.data-preview-header{
  background: rgb(39,35,35) 
}


.data-preview-header-icon{
    margin: 6px;
    font-size: 20px;
}

.data-preview-title .title {
  color: white;
  margin-left: 20px;
  font-size: 15px;
  margin-top: 10px;
}

.data-preview-title{
    height: 100%;    
}


.data-preview{
    
  width: 70%;
  float: left;
     
 }
 
 .div-to-display {
  display: none;
  position: absolute;
  top: -300%;
  left: 100%;
  /* border: 1px solid red; */
  background-color: #eee;
  z-index: 100;
  
}
#float-menu {
  position: relative;
}
#float-menu:hover > .div-to-display {
  display: block
}

#var-button {

  background-color: #322c61; 
  color: white;
  float: left;
  width: 80px;
  height: 36px;
  border: none;
}

.div-to-display {
  background: rgb(198,195,195);
  width: 350px;
  height: 100px;
}

#lname{
  float: left;
  height: 40px;
  width: 225px;
  margin-left: 5px;
  margin-right: 5px;
  margin-top: 0px;
}

#var-button:hover{
  background-color: #49465c; 
  color: white;
  float: left;
  width: 100px;
  height: 38px;
  border: none;
  
}

[id^="uid-"][id$="-sections"] {
  background: rgb(227,227,227);
  border: 1px #777 solid;
  cursor: pointer;
  padding-top: 10px;
  padding-bottom: 10px;
  border: none;
  text-align: left;
  outline: none;
  font-size: 15px;
  width: 98%;
  margin: 0px;
  margin-left: 0.5%;
  padding-left: 2%;
  padding-right: 2%;
  border-radius: 0px;
  border-bottom-left-radius:3px; 
  border-bottom-right-radius: 3px; 
  border-left: 1px #777 solid;
  border-bottom:  1px #777 solid;
}

.galaxy-uibuilder .conditional{
  margin: 0px;
  padding: 0px;
 width: 100%;
}

.galaxy-uibuilder .conditional select{
width: 98%;
margin-left: 0.5%;
}

[id^="select-uid-"] {
  width: 99%;
}

.galaxy-uibuilder [id^="input-uid-"]:not([type="checkbox"]) {
  width: 99%;
}

.galaxy-uibuilder .outer-checkbox-div input{
  width: 10px;
  height: 10px;
  
}