"use strict";(self.webpackChunkGiN=self.webpackChunkGiN||[]).push([[480],{4480:(e,t,n)=>{n.r(t),n.d(t,{default:()=>b});var a=n(6728),r=n(5687),o=n(1123),i=n(5344),s=n(4080),u=n(7455),c=n(841),g=n(6988);n(8657),n(7936);const p=Object.assign(Object.assign(Object.assign({},c),g)),b={id:"GiN:plugin",requires:[a.IJupyterWidgetRegistry],optional:[i.IMainMenu,r.ILayoutRestorer,r.ILabShell,o.INotebookTracker],activate:function(e,t,n,a,r,o){!function(e,t){u.ContextManager.jupyter_app=e,u.ContextManager.notebook_tracker=t,u.ContextManager.context()}(e,o);const i=new s.Ld,c=new u.ToolRegistry;return t.registerWidget({name:"GiN",version:"0.1.0",exports:p}),[c,i]},autoStart:!0}}}]);